@@ -13,7 +13,7 @@
 ##############################################################################
 """Test tcpdoc
 
-$Id: tests.py 90123 2008-08-22 13:37:35Z fdrake $
+$Id: tests.py 100907 2009-06-12 20:18:51Z icemac $
 """
 import os
 import re
@@ -473,7 +473,7 @@ def doctest_FunctionalTestSetup_supports_product_config():
 
         >>> def handle_database_open(event):
         ...     global config
-        ...     IDbOE = zope.app.appsetup.interfaces.IDatabaseOpenedEvent
+        ...     IDbOE = zope.processlifetime.IDatabaseOpened
         ...     if IDbOE.providedBy(event):
         ...         config = zope.app.appsetup.product.getProductConfiguration(
         ...             'abc')
@@ -612,7 +612,8 @@ def test_suite():
     RetryProblemFunctional.layer = AppTestingLayer
     RetryProblemBrowser.layer = AppTestingLayer
 
-    doc_test = FunctionalDocFileSuite('doctest.txt', checker=checker)
+    doc_test = FunctionalDocFileSuite('doctest.txt', 'cookieTestOne.txt',
+        'cookieTestTwo.txt', checker=checker)
     doc_test.layer = AppTestingLayer
 
     return unittest.TestSuite((
